@@ -15,14 +15,15 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef MAILCOMMON_BACKUPJOB_H
 #define MAILCOMMON_BACKUPJOB_H
 
 #include "mailcommon_export.h"
-#include "libkdepim/progressmanager.h"
+
+#include <Libkdepim/ProgressManager>
 
 #include <Collection>
 #include <Item>
@@ -38,14 +39,11 @@ class KJob;
 
 class QWidget;
 
-namespace Akonadi
-{
+namespace Akonadi {
 class ItemFetchJob;
 }
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 /**
  * Writes an entire folder structure to an archive file. The archive is
  * structured like a hierarchy of maildir folders. However, every type of
@@ -53,7 +51,7 @@ namespace MailCommon
  *
  * The job deletes itself after it finished.
  */
-class  MAILCOMMON_EXPORT BackupJob : public QObject
+class MAILCOMMON_EXPORT BackupJob : public QObject
 {
     Q_OBJECT
 
@@ -108,8 +106,8 @@ private:
     QDateTime mArchiveTime;
     ArchiveType mArchiveType;
     Akonadi::Collection mRootFolder;
-    KArchive *mArchive;
-    QWidget *mParentWidget;
+    KArchive *mArchive = nullptr;
+    QWidget *mParentWidget = nullptr;
     int mArchivedMessages;
     uint mArchivedSize;
     QPointer<KPIM::ProgressItem> mProgressItem;
@@ -121,10 +119,9 @@ private:
     Akonadi::Collection::List mAllFolders;
     Akonadi::Collection mCurrentFolder;
     Akonadi::Item::List mPendingMessages;
-    Akonadi::ItemFetchJob *mCurrentJob;
-    bool mDisplayMessageBox;
+    Akonadi::ItemFetchJob *mCurrentJob = nullptr;
+    bool mDisplayMessageBox = false;
 };
-
 }
 
 #endif
